# Entry title

Entry note 0, a single note spanning multiple
lines until a list is found.

- Entry note one
  with multiple lines
- Entry note two with one line

> tag tag1,tag2 tag3 commas spaces means,split
> status in-progress
> reminder time here

# Comprar batatas 

- Ir ao mercado comprar muitas batatas e depois cozinhar
  compras as melhores batatas
  batatas bonitas

> tag food compras
> reminder 2 minutes

# Testar a implementação do Dolist

- Testar todos os casos de uso do dolist e garantir 
  que tudo funciona perfeitamente.
- Publicar post no blog

> tag tech,code 
> reminder 2 hours
> status in-progress


# Gravar video sobre o projeto

- Gravar video explicando todo o projeto dolist
  e postar nas redes sociais.
- Editar video.
- Acompanhar metricas do video.

> tag video tech
> reminder 2 weeks
